Proportion of confidence intervals that contain the true effect. Optionally applies an empirical correction factor to the standard errors before constructing intervals.
See also
Other simulation-performance:
sim_bias(),
sim_correct_rejection_rate(),
sim_correction_factor(),
sim_mse(),
sim_rejection_rate(),
sim_type_s_error(),
summarize_simulation()